// @flow
// AUTH - TEST HELPERS
// =============================================================================

import { expect } from 'chai';
import type FetchMock from 'fetch-mock';

const initialState =
  { environment: { kahunaPath: 'kahuna', detectedRegion: 'AU' },
    intl: { locale: 'en-AU' },
    user: { token_issued: 'token' },
  };

export const JsonResponseOptions = {
  headers: {
    'Content-Type': 'application/json',
  },
  sendAsJson: true,
};

export const getInitialState = (additionalState?: Object) => ({ ...initialState, ...additionalState });

// Returns request and parsed request body if it exists
function checkExpectedHeaders(mockFetch: FetchMock) {
  const lastCall = mockFetch.lastCall();
  if (!lastCall) {
    throw new Error('No request to verify!');
  }

  const request = lastCall[1];
  expect(request.mode).to.equal('cors');
  expect(request.headers.get('Content-Type')).to.equal('application/json');
  expect(request.headers.get('Trov-Client')).to.equal('tofino');
  expect(request.headers.get('Trov-Market')).to.equal('AU');
  expect(request.headers.get('Accept-Language')).to.equal('en-AU');
  return request;
}

export const verifyRequest = (mockFetch: FetchMock): Array<Object> => {
  const request = checkExpectedHeaders(mockFetch);

  const result = [request];
  if (request.body) {
    result.push(JSON.parse(request.body));
  }

  return result;
};

// Returns request and parsed request body if it exists
export const verifyTokenRequest = (mockFetch: FetchMock): Array<Object> => {
  const request = checkExpectedHeaders(mockFetch);

  const result = [request];
  if (request.body) {
    result.push(request.body);
  }

  return result;
};
