// DEVELOP.SH CUSTOM ESLINT REPORTER
// =============================================================================
// Outputs eslint results in a simple format so they can be scraped by
// DEVELOP.sh

function reporter ( results = [] ) {
  var summary = results.reduce( ( seq, current ) => {
    current.messages.forEach( msg => {
      let logMessage =
        { filePath : current.filePath
        , ruleId   : msg.ruleId
        , message  : msg.message
        , line     : msg.line
        , column   : msg.column
        , source   : msg.sourc
        };

        if ( msg.severity === 1 ) {
          logMessage.type = "warning";
          seq.warnings.push( logMessage );
        }
        if ( msg.severity === 2 ) {
          logMessage.type = "error";
          seq.errors.push( logMessage );
        }
      } );

      return seq;
    }
    , { errors   : []
      , warnings : []
      }
    );

  var errorReport = summary.errors.concat( summary.warnings ).map( msg => {
    return `TYPE:${ msg.type.toUpperCase() }: ${ msg.message }LOCATION:${ msg.filePath }:${ msg.line }:${ msg.column }`;
  } ).join( "\n" );


  return `${ summary.warnings.length } ${ summary.errors.length } ${ errorReport }`;
}

module.exports = reporter;
