// BASE - WEBPACK CONFIG
// =============================================================================
// Provides core settings and options that are used by all other webpack
// configuration files. Avoid repeating definitions by creating named exports
// in this file instead.

const path    = require( "path" );
const fs      = require( "fs" );
const webpack = require( "webpack" );

const LOCAL_TURBOKIT = process.env.LOCAL_TURBOKIT === 'true'

const paths =
  { node_modules : path.join( __dirname, "..", "node_modules" )
    , dist         : path.join( __dirname, "..", "dist" )
    , public       : path.join( __dirname, "..", "public" )
    , favicons     : path.join( __dirname, "..", "public", "favicons" )
    , assets       : path.join( __dirname, "..", "dist", "assets" )
    , stats        : path.join( __dirname, "..", "dist", "stats.generated.json" )
    , scriptSrc    : path.join( __dirname, "..", "src", "scripts" )
    , styleSrc     : path.join( __dirname, "..", "src", "styles" )
    , fontSrc      : path.join( __dirname, "..", "src", "fonts" )
    , imageSrc     : path.join( __dirname, "..", "src", "images" )
    , turbokit     : LOCAL_TURBOKIT
    ? path.join( __dirname, "..", "..", "TurboKit")
    : path.join( __dirname, "..", "node_modules", "@troveng", "turbokit" )
  };

const regex =
  { script : /\.(js|jsx)$/
    , json   : /\.(json|schema)$/
    , file   : /\.(woff|woff2|svg|png|jpg|jpeg|ico)/
    , style  : /\.(css|scss)$/
  };

const plugins =
  { development:
    [ new webpack.optimize.OccurrenceOrderPlugin()
      , new webpack.NoEmitOnErrorsPlugin()
    ]
    , production:
    [ new webpack.optimize.OccurrenceOrderPlugin()
      , new webpack.optimize.AggressiveMergingPlugin()
    ]
  };

const loaders =
  // SCRIPTS
  { script:
    { test   : regex.script
      , loader : "babel-loader"
      , include :
      [ paths.scriptSrc
      ]
      , query:
      { "presets":
        [ [ "es2015"
          , { "loose"   : true
            , "modules" : false
          }
        ]
          , "stage-0"
          , "react"
        ]

        , retainLines    : true
        , cacheDirectory : true
      }
    }

    // STYLESHEETS
    , style:
    { test    : regex.style
      , loaders:
      [ "style-loader"
        , "css-loader"
        , "sass-loader"
      ]
      , include:
      [ paths.styleSrc
        , paths.scriptSrc
      ]
    }

    // JSON
    , json:
    { test   : regex.json
      , loader : "json-loader"
      , query  : { name: "[name].[ext]" }
    }

    // FONTS AND IMAGES
    , file:
    { test   : regex.file
      , loader : "url-loader"
      , query:
      { limit : 5000
        , name  : "[name].[ext]"
      }
      , include:
      [ paths.imageSrc
        , paths.fontSrc
        , paths.node_modules
        , paths.turbokit
      ]
    }
  };

module.exports = { paths, regex, plugins, loaders, LOCAL_TURBOKIT }