// DEVELOPMENT - WEBPACK CONFIG
// =============================================================================
const path = require( "path" );
const webpack = require( "webpack" );
const FriendlyErrorsWebpackPlugin = require( "friendly-errors-webpack-plugin" );

const { paths, plugins, loaders, LOCAL_TURBOKIT } = require( "./base.webpack.config" );
const { protocol, host, port } = require( "../webserver/config" );
const packageInfo = require('../package.json');
const getNodeEnv = require('../shared/environment/getNodeEnv');
const getApiEnv = require('../shared/environment/getApiEnv');

const VERSION = JSON.stringify(packageInfo.version);
const BUILD_NUMBER = JSON.stringify(process.env.BUILD_NUMBER);
const GIT_COMMIT = JSON.stringify(process.env.GIT_COMMIT);
const DEV_TOOLS = JSON.stringify(true);
const API_ENV = JSON.stringify(getApiEnv());
const NODE_ENV = JSON.stringify(getNodeEnv());

const friendlyConfig =
  { compilationSuccessInfo:
    { messages: [ `Development server running: ${ protocol }://${ host }:${ port }` ]
    }
    , shouldClearConsole: false
  };

module.exports =
  [ { name        : "client"
    , performance : { hints : false }
    , devtool     : "eval-source-map"
    , entry:
      [ "babel-polyfill"
        , "webpack-hot-middleware/client"
        , path.join( paths.scriptSrc, "browser.js" )
      ]
    , output:
      { path       : paths.assets
        , filename   : "[hash].js"
        , publicPath : "/assets/"
      }
    , plugins:
      [ ...plugins.development
        , new webpack.HotModuleReplacementPlugin()
        , new webpack.DefinePlugin(
        { "process.env":
          { BROWSER   : JSON.stringify( true )
            , NODE_ENV
            , API_ENV
            , DEV_TOOLS
            , VERSION
            , GIT_COMMIT
            , BUILD_NUMBER
          }
        }
      )
      ]
    , resolve:
      { alias:
        { '@troveng/turbokit': LOCAL_TURBOKIT
          ? path.resolve('../TurboKit')
          : '@troveng/turbokit'
        }
      }
    , module:
      { loaders:
        [ loaders.script
          , loaders.style
          , loaders.json
          , loaders.file
        ]
      }
  }
    , { name        : "server"
    , performance : { hints : false }
    , devtool     : "cheap-module-inline-source-map"
    , target      : "node"
    , externals   : /^[a-z\-0-9]+$/
    , entry:
      [ "babel-polyfill"
        , path.join( paths.scriptSrc, "server.js" )
      ]
    , output:
      { path          : paths.assets
        , filename      : "server.js"
        , publicPath    : "/assets/"
        , libraryTarget : "commonjs2"
      }
    , plugins:
      [ ...plugins.development
        , new FriendlyErrorsWebpackPlugin( friendlyConfig )
        , new webpack.DefinePlugin(
        { "process.env":
          { BROWSER   : JSON.stringify( false )
            , NODE_ENV
            , API_ENV
            , DEV_TOOLS
            , VERSION
            , GIT_COMMIT
            , BUILD_NUMBER
          }
        }
      )
      ]
    , resolve:
      { alias:
        { '@troveng/turbokit': LOCAL_TURBOKIT
          ? path.resolve('../TurboKit')
          : '@troveng/turbokit'
        }
      }
    , module:
      { loaders:
        [ loaders.script
          , loaders.style
          , loaders.json
          , loaders.file
        ]
      }
  }
  ];