// PRODUCTION - WEBPACK CONFIG
// =============================================================================
const fs = require( "fs" );
const path = require( "path" );
const webpack = require( "webpack" );
const ExtractTextPlugin = require( "extract-text-webpack-plugin" );

const { paths, plugins, loaders } = require( "./base.webpack.config" );
const packageInfo = require('../package.json');
const getNodeEnv = require('../shared/environment/getNodeEnv');
const getApiEnv = require('../shared/environment/getApiEnv');
const getDeployRegion = require('../shared/environment/getDeployRegion');

const extractSASS = new ExtractTextPlugin( "main.css" );
const VERSION = JSON.stringify(packageInfo.version);
const BUILD_NUMBER = JSON.stringify(process.env.BUILD_NUMBER);
const GIT_COMMIT = JSON.stringify(process.env.GIT_COMMIT);
const DEV_TOOLS = JSON.stringify(getApiEnv() !== "production");
const NODE_ENV = JSON.stringify(getNodeEnv());
const API_ENV = JSON.stringify(getApiEnv());
const DEPLOY_REGION = JSON.stringify(getDeployRegion());

module.exports =
  [ { name    : "client"
    , devtool : "source-map"
    , entry:
      [ "babel-polyfill"
        , path.join( paths.scriptSrc, "browser.js" )
      ]
    , output:
      { path              : paths.assets
        , publicPath        : "/assets/"
        , filename          : "[hash].js"
        , sourceMapFilename : "[file].map"
      }
    , plugins:
      [ ...plugins.production
        , new webpack.optimize.UglifyJsPlugin(
        { compress  : { warnings: false }
          , output    : { comments: false }
          , sourceMap : true
        }
      )
        , new webpack.optimize.CommonsChunkPlugin(
        { name      : "vendor"
          , filename  : "vendor.js"
          , minChunks : module => /node_modules/.test( module.resource )
        }
      )
        , extractSASS
        , function () {
        this.plugin( "done", stats => {
          fs.writeFileSync( paths.stats, JSON.stringify( stats.toJson() ) );
        });
      }
        , new webpack.DefinePlugin(
        { "process.env":
          { BROWSER   : JSON.stringify( true )
            , NODE_ENV
            , API_ENV
            , DEV_TOOLS
            , DEPLOY_REGION
            , VERSION
            , GIT_COMMIT
            , BUILD_NUMBER
          }
        }
      )
      ]
    , module:
      { loaders:
        [ loaders.script
          , { test: /\.(css|scss)$/
          , loaders: extractSASS.extract([ "css-loader", "sass-loader" ])
          , include:
            [ path.resolve( "./src/styles" )
              , path.resolve( "./src/scripts" )
            ]
        }
          , loaders.json
          , loaders.file
        ]
      }
  }
    , { name      : "server"
    , devtool   : "source-map"
    , target    : "node"
    , externals : /^[a-z\-0-9]+$/
    , entry:
      [ "babel-polyfill"
        , path.join( paths.scriptSrc, "server.js" )
      ]
    , output:
      { path              : paths.dist
        , publicPath        : "/assets/"
        , filename          : "server.js"
        , sourceMapFilename : "[file].map"
        , libraryTarget     : "commonjs2"
      }
    , plugins:
      [ ...plugins.production
        , new webpack.DefinePlugin(
        { "process.env":
          { BROWSER   : JSON.stringify( false )
            , NODE_ENV
            , API_ENV
            , DEV_TOOLS
            , DEPLOY_REGION
            , VERSION
            , GIT_COMMIT
            , BUILD_NUMBER
          }
        }
      )
      ]
    , module:
      { loaders:
        [ loaders.script
          , loaders.style
          , loaders.json
          , loaders.file
        ]
      }
  }
  ];